import type { APIRoute } from "astro";
import validateAccessToken from "../../../lib/utils/validateAccessToken";
import { getAccessToken } from "../../../lib/db/accessTokens";

export const GET: APIRoute = async({ request }) => {
    const response = await validateAccessToken(request);
    if(response instanceof Response) return response;

    const accessToken = await getAccessToken(response);
    if(!accessToken) return new Response(
        JSON.stringify({
            code: 404,
            message: "Not Found",
            data: "Access token not found"
        }), { status: 404 }
    );

    return new Response(
        JSON.stringify({
            code: 200,
            message: "OK",
            data: "Access token valid for user " + accessToken.username
        })
    );
}